@@ -8,7 +8,7 @@ from njsscan import __version__
 from njsscan.njsscan import NJSScan
 from njsscan.formatters import (
     cli,
-    json,
+    json_out,
     sarif,
     sonarqube,
 )
@@ -45,9 +45,15 @@ def main():
     parser.add_argument('--sonarqube',
                         help='set output format compatible with SonarQube',
                         action='store_true')
+    parser.add_argument('--html',
+                        help='set output format as HTML',
+                        action='store_true')
     parser.add_argument('-o', '--output',
                         help='output filename to save the result',
                         required=False)
+    parser.add_argument('-c', '--config',
+                        help='Location to .njsscan config file',
+                        required=False)
     parser.add_argument('--missing-controls',
                         help='enable missing security controls check',
                         action='store_true',
@@ -67,19 +73,39 @@ def main():
             args.path,
             is_json,
             args.missing_controls,
+            args.config,
         ).scan()
         if args.sonarqube:
-            sonarqube.sonarqube_output(args.output, scan_results)
+            sonarqube.sonarqube_output(
+                args.output,
+                scan_results,
+                __version__)
         elif args.json:
-            json.json_output(args.output, scan_results)
+            json_out.json_output(
+                args.output,
+                scan_results,
+                __version__)
         elif args.sarif:
-            sarif.sarif_output(args.output, scan_results, __version__)
+            sarif.sarif_output(
+                args.output,
+                scan_results,
+                __version__)
+        elif args.html:
+            cli.cli_output(
+                args.output,
+                scan_results,
+                __version__,
+                'unsafehtml')
         else:
-            cli.cli_output(args.output, scan_results)
+            cli.cli_output(
+                args.output,
+                scan_results,
+                __version__,
+                'fancy_grid')
         handle_exit(scan_results, args.exit_warning)
 
     elif args.version:
-        print('njsscan: v' + __version__)
+        cli.print_tool_info(__version__)
     else:
         parser.print_help()
 
